@@ -503,7 +503,9 @@ class FakeOsModule:
 
         path_str = self.filesystem.cwd if path is None else path
         file_obj = self.filesystem.resolve(
-            cast(AnyStr, path_str), follow_symlinks, allow_fd=True
+            cast(AnyStr, path_str),  # pytype: disable=invalid-annotation
+            follow_symlinks,
+            allow_fd=True,
         )
         return list(file_obj.xattr.keys())
 
@@ -1346,7 +1348,7 @@ if sys.version_info > (3, 10):
 
         @functools.wraps(f)
         def wrapped(*args, **kwargs):
-            if not f.__name__.startswith("_") and FakeOsModule.use_original:
+            if FakeOsModule.use_original:
                 # remove the `self` argument for FakeOsModule methods
                 if args and isinstance(args[0], FakeOsModule):
                     args = args[1:]
@@ -1356,7 +1358,8 @@ if sys.version_info > (3, 10):
         return wrapped
 
     for name, fn in inspect.getmembers(FakeOsModule, inspect.isfunction):
-        setattr(FakeOsModule, name, handle_original_call(fn))
+        if not fn.__name__.startswith("_"):
+            setattr(FakeOsModule, name, handle_original_call(fn))
 
 
 @contextmanager
